@@ -1,23 +1,23 @@
-/*
-    GNOME Commander - A GNOME based file manager
-    Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2016 Uwe Scholz
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
+/** 
+ * @file gnome-cmd-manage-bookmarks-dialog.cc
+ * @copyright (C) 2001-2006 Marcus Bjurman\n
+ * @copyright (C) 2007-2012 Piotr Eljasiak\n
+ * @copyright (C) 2013-2016 Uwe Scholz\n
+ *
+ * @copyright This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * @copyright This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * @copyright You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #include <config.h>
 #include <map>
@@ -65,6 +65,7 @@ enum
 
 const int RESPONSE_JUMP_TO = 123;
 
+GtkWidget *view = NULL;
 
 void gnome_cmd_bookmark_dialog_new (const gchar *title, GtkWindow *parent)
 {
@@ -79,7 +80,7 @@ void gnome_cmd_bookmark_dialog_new (const gchar *title, GtkWindow *parent)
     GtkWidget *content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 #endif
 
-    GtkWidget *vbox, *hbox, *scrolled_window, *view, *button;
+    GtkWidget *vbox, *hbox, *scrolled_window, *button;
 
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
     gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
@@ -158,17 +159,13 @@ void gnome_cmd_bookmark_dialog_new (const gchar *title, GtkWindow *parent)
     gtk_dialog_run (GTK_DIALOG (dialog));
 
     gtk_widget_destroy (dialog);
+    view = NULL;
 }
 
 
-static GtkTreeModel *create_and_fill_model (GtkTreePath *&current_group)
+static void fill_tree (GtkTreeStore *store, GtkTreePath *&current_group)
 {
-    GtkTreeStore *store = gtk_tree_store_new (NUM_COLUMNS,
-                                              G_TYPE_STRING,
-                                              G_TYPE_STRING,
-                                              G_TYPE_STRING,
-                                              G_TYPE_STRING,
-                                              G_TYPE_POINTER);
+    gtk_tree_store_clear (store);
 
     GnomeCmdCon *current_con = main_win->fs(ACTIVE)->get_connection();
     GtkTreeIter toplevel;
@@ -219,6 +216,19 @@ static GtkTreeModel *create_and_fill_model (GtkTreePath *&current_group)
                                 -1);
         }
     }
+}
+
+
+static GtkTreeModel *create_and_fill_model (GtkTreePath *&current_group)
+{
+    GtkTreeStore *store = gtk_tree_store_new (NUM_COLUMNS,
+                                              G_TYPE_STRING,
+                                              G_TYPE_STRING,
+                                              G_TYPE_STRING,
+                                              G_TYPE_STRING,
+                                              G_TYPE_POINTER);
+    fill_tree (store, current_group);
+    
 
     return GTK_TREE_MODEL (store);
 }
@@ -290,6 +300,18 @@ static GtkWidget *create_view_and_model ()
 }
 
 
+void gnome_cmd_update_bookmark_dialog ()
+{
+    if (view)
+    {
+        GtkTreePath *group = NULL;
+        fill_tree (GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (view))), group);
+        if (group)
+            gtk_tree_view_expand_row (GTK_TREE_VIEW (view), group, TRUE);
+    }
+}
+
+
 static void cursor_changed_callback (GtkTreeView *view, GtkWidget *dialog)
 {
     GtkTreeModel *model = gtk_tree_view_get_model (view);
@@ -358,6 +380,10 @@ static void remove_clicked_callback (GtkButton *button, GtkWidget *view)
             g_free (bookmark->name);
             g_free (bookmark->path);
             g_free (bookmark);
+            
+            main_win->update_bookmarks ();
+            
+            gnome_cmd_data.save_xml ();
         }
     }
 }
@@ -550,6 +576,8 @@ void gnome_cmd_bookmark_add_current (GnomeCmdDir *dir)
         group->bookmarks = g_list_append (group->bookmarks, bookmark);
 
         main_win->update_bookmarks();
+        
+        gnome_cmd_data.save_xml ();
     }
     else
     {
