@@ -1,27 +1,26 @@
-/*
-    GNOME Commander - A GNOME based file manager
-    Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2016 Uwe Scholz
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
- 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
+/** 
+ * @file gnome-cmd-about-plugin.cc
+ * @copyright (C) 2001-2006 Marcus Bjurman\n
+ * @copyright (C) 2007-2012 Piotr Eljasiak\n
+ * @copyright (C) 2013-2016 Uwe Scholz\n
+ *
+ * @copyright This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * @copyright This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * @copyright You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #include <config.h>
 #include <libgnomeui/gnome-href.h>
-#include <libgnomeui/gnome-stock-icons.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-about-plugin.h"
@@ -147,6 +146,8 @@ static void gnome_cmd_about_plugin_update_translation_information_label (GnomeCm
     g_string_append (string, tmp);
     g_free (tmp);
 
+    g_string_append_c (string, '\n');
+
     gtk_label_set_markup (GTK_LABEL (label), string->str);
     g_string_free (string, TRUE);
 }
@@ -293,7 +294,7 @@ static void gnome_cmd_about_plugin_init (GnomeCmdAboutPlugin *about)
     gtk_dialog_set_default_response (GTK_DIALOG (about), GTK_RESPONSE_CLOSE);
 
     // Add the credits button
-    image = gtk_image_new_from_stock (GNOME_STOCK_ABOUT, GTK_ICON_SIZE_BUTTON);
+    image = gtk_image_new_from_stock (GTK_STOCK_ABOUT, GTK_ICON_SIZE_BUTTON);
 
     label = gtk_label_new_with_mnemonic (_("C_redits"));
 
@@ -598,21 +599,15 @@ static void gnome_cmd_about_plugin_set_persons (GnomeCmdAboutPlugin *about, guin
 static void set_value_array_from_list (GValue *value, GSList *list)
 {
     gint length = g_slist_length (list);
-    GValueArray *array = g_value_array_new (length);
-
-    GValue tmp_value = { 0 };
+    GArray *array = g_array_sized_new (FALSE, TRUE, sizeof(char*), length);
 
     for (GSList *i = list; i; i = i->next)
     {
-        char *str = (char *) i->data;
-
-        g_value_init (&tmp_value, G_TYPE_STRING);
-        g_value_set_string (&tmp_value, str);
-        g_value_array_append (array, &tmp_value);
+        g_array_append_val (array, i->data);
     }
 
     g_value_set_boxed (value, array);
-    g_value_array_free (array);
+    g_array_free (array, TRUE);
 }
 
 
@@ -689,21 +684,21 @@ static void gnome_cmd_about_plugin_get_property (GObject *object, guint prop_id,
 
 
 /**
- * gnome_cmd_about_plugin_construct:
- * @about: An existing #GnomeCmdAboutPlugin instance.
- * @name: The name of the application.
- * @version: The version string of the application.
- * @copyright: The application's copyright statement.
- * @comments: A short miscellaneous string.
- * @authors: An %NULL terminated array of the application authors.
- * @documenters: An array of the application documenters.
- * @translator_credits: The translator for the current locale.
- * @webpage: The plugins's webpage.
- *
- * Similar to gnome_cmd_about_plugin_new() except that the pre-existing @about widget is
- * used. Note that in this version of the function, @authors is not checked to
- * be non-%NULL, so callers must be careful, since bad things will happen if
- * this condition is not met.
+ * Similar to gnome_cmd_about_plugin_new() except that the pre-existing
+ * GnomeCmdAboutPlugin widget is used. Note that in this version of the
+ * function, @c authors is not checked to be non-NULL, so callers must
+ * be careful, since bad things will happen if this condition is not
+ * met.
+ * 
+ * @param about An existing GnomeCmdAboutPlugin instance.
+ * @param name The name of the application.
+ * @param version The version string of the application.
+ * @param copyright The application's copyright statement.
+ * @param comments A short miscellaneous string.
+ * @param authors An %NULL terminated array of the application authors.
+ * @param documenters An array of the application documenters.
+ * @param translator_credits The translator for the current locale.
+ * @param webpage The plugins's webpage.
  */
 void gnome_cmd_about_plugin_construct (GnomeCmdAboutPlugin *about,
                                        const gchar  *name,
@@ -715,69 +710,50 @@ void gnome_cmd_about_plugin_construct (GnomeCmdAboutPlugin *about,
                                        const gchar  *translator_credits,
                                        const gchar  *webpage)
 {
-    GValueArray *authors_array = g_value_array_new (0);
-    GValueArray *documenters_array;
+    GArray *authors_array = g_array_new (FALSE, FALSE, sizeof(char*));
+    GArray *documenters_array = NULL;
 
     for (gint i = 0; authors[i] != NULL; i++)
     {
-        GValue value = {0, };
-
-        g_value_init (&value, G_TYPE_STRING);
-        g_value_set_static_string (&value, authors[i]);
-        authors_array = g_value_array_append (authors_array, &value);
+        authors_array = g_array_append_val (authors_array, authors[i]);
     }
 
     if (documenters)
     {
-        documenters_array = g_value_array_new (0);
+        documenters_array = g_array_new (FALSE, FALSE, sizeof(char*));
 
         for (gint i = 0; documenters[i] != NULL; i++)
         {
-            GValue value = {0, };
-
-            g_value_init (&value, G_TYPE_STRING);
-            g_value_set_static_string (&value, documenters[i]);
-            documenters_array = g_value_array_append (documenters_array, &value);
+            documenters_array = g_array_append_val (documenters_array, documenters[i]);
         }
 
     }
-    else
-        documenters_array = NULL;
 
     g_object_set (G_OBJECT (about),
                   "name", name,
                   "version", version,
                   "copyright", copyright,
                   "comments", comments,
-                  "authors", authors_array,
-                  "documenters", documenters_array,
+//                  "authors", authors_array,
+//                  "documenters", documenters_array,
                   "translator_credits", translator_credits,
                   "webpage", webpage,
                   NULL);
 
     if (authors_array)
-        g_value_array_free (authors_array);
+        g_array_free (authors_array, TRUE);
 
     if (documenters_array)
-        g_value_array_free (documenters_array);
+        g_array_free (documenters_array, TRUE);
 }
 
 
 /**
- * gnome_cmd_about_plugin_new:
- * @name: The name of the application.
- * @version: The version string of the application.
- * @copyright: The application's copyright statement.
- * @comments: A short miscellaneous string.
- * @authors: An %NULL terminated array of the application authors.
- * @documenters: An array of the application documenters.
- * @translator_credits: The translator for the current locale.
- *
- * Construct an application's credits box. The @authors array cannot be empty
- * and the @translator_credits should be marked as a translatable string (so
+ * Construct an application's credits box. The authors array cannot be empty
+ * and the translator_credits should be marked as a translatable string (so
  * that only the translator for the currently active locale is displayed).
  *
- * Returns: A new "About" dialog.
+ * @returns A new "About" dialog.
  */
 GtkWidget *gnome_cmd_about_plugin_new (PluginInfo *info)
 {
