@@ -1,30 +1,32 @@
-/*
-    GNOME Commander - A GNOME based file manager
-    Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2015 Uwe Scholz
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
+/** 
+ * @file gnome-cmd-con-list.cc
+ * @copyright (C) 2001-2006 Marcus Bjurman\n
+ * @copyright (C) 2007-2012 Piotr Eljasiak\n
+ * @copyright (C) 2013-2016 Uwe Scholz\n
+ *
+ * @copyright This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * @copyright This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * @copyright You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #include <config.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-con-home.h"
-#include "gnome-cmd-con-smb.h"
 #include "gnome-cmd-con-list.h"
+#ifdef HAVE_SAMBA
+#include "gnome-cmd-con-smb.h"
+#endif
 
 using namespace std;
 
@@ -42,8 +44,9 @@ struct GnomeCmdConList::Private
     GList *quick_ftp_cons;
 
     GnomeCmdCon *home_con;
+#ifdef HAVE_SAMBA
     GnomeCmdCon *smb_con;
-
+#endif
     GList *all_cons;
 };
 
@@ -146,13 +149,16 @@ static void init (GnomeCmdConList *con_list)
     con_list->priv->update_lock = FALSE;
 
     con_list->priv->home_con = gnome_cmd_con_home_new ();
+#ifdef HAVE_SAMBA
     con_list->priv->smb_con = gnome_cmd_con_smb_new ();
-
+#endif
     // con_list->priv->remote_cons = NULL;
     // con_list->priv->device_cons = NULL;
     // con_list->priv->quick_ftp_cons = NULL;
     con_list->priv->all_cons = g_list_append (NULL, con_list->priv->home_con);
+#ifdef HAVE_SAMBA
     con_list->priv->all_cons = g_list_append (con_list->priv->all_cons, con_list->priv->smb_con);
+#endif
 }
 
 
@@ -395,8 +401,9 @@ GnomeCmdCon *GnomeCmdConList::get_home()
     return priv->home_con;
 }
 
-
+#ifdef HAVE_SAMBA
 GnomeCmdCon *GnomeCmdConList::get_smb()
 {
     return priv->smb_con;
 }
+#endif
