@@ -765,6 +765,9 @@ static void class_init (GnomeCmdFileSelectorClass *klass)
 
 static void init (GnomeCmdFileSelector *fs)
 {
+    gint string_size = 0;
+    gint max_string_size = 150;
+
     fs->list = NULL;
 
     fs->priv = new GnomeCmdFileSelector::Private;
@@ -780,11 +783,29 @@ static void init (GnomeCmdFileSelector *fs)
     // create the notebook and the first tab
     fs->notebook = new GnomeCmdNotebook;
 
+    for (GList *l=gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ()); l; l = l->next)
+    {
+        gchar *text;
+        GnomeCmdCon *con = (GnomeCmdCon *) l->data;
+
+#ifdef HAVE_SAMBA
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con)
+            && !GNOME_CMD_IS_CON_SMB (con))  continue;
+#else
+        if (!gnome_cmd_con_is_open (con) && !GNOME_CMD_IS_CON_DEVICE (con))  continue;
+#endif
+
+        text = g_strdup_printf("%s  ",(gchar *) gnome_cmd_con_get_alias (con));
+        string_size = get_string_pixel_size (text, strlen(text));
+        max_string_size = string_size > max_string_size ? string_size : max_string_size;
+        g_free(text);
+    }
+
     // create the connection combo
     fs->con_combo = new GnomeCmdCombo(2, 1);
     g_object_ref (fs->con_combo);
     g_object_set_data_full (*fs, "con_combo", fs->con_combo, g_object_unref);
-    gtk_widget_set_size_request (*fs->con_combo, 150, -1);
+    gtk_widget_set_size_request (*fs->con_combo, max_string_size, -1);
     gtk_clist_set_row_height (GTK_CLIST (fs->con_combo->list), 20);
     gtk_entry_set_editable (GTK_ENTRY (fs->con_combo->entry), FALSE);
     gtk_clist_set_column_width (GTK_CLIST (fs->con_combo->list), 0, 20);
@@ -816,7 +837,11 @@ static void init (GnomeCmdFileSelector *fs)
     gtk_box_pack_start (GTK_BOX (vbox), padding, FALSE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (padding), fs->info_label, FALSE, TRUE, 6);
     gtk_box_pack_start (GTK_BOX (fs->con_hbox), *fs->con_combo, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (fs->con_hbox), fs->vol_label, TRUE, TRUE, 6);
+    // changing this value has only an effect when restarting gcmd
+    if (gnome_cmd_data.show_devlist)
+        gtk_box_pack_start (GTK_BOX (fs->con_hbox), fs->vol_label, TRUE, TRUE, 6);
+    else
+        gtk_box_pack_start (GTK_BOX (padding), fs->vol_label, TRUE, TRUE, 6);
 
     // connect signals
     g_signal_connect (fs, "realize", G_CALLBACK (on_realize), fs);
